@@ -840,7 +840,7 @@ gnumeric_indirect (FunctionEvalInfo *ei, GnmValue const * const *args)
 	char const *text = value_peek_string (args[0]);
 	GnmExprConventions const *convs = gnm_expr_conventions_default;
 
-	if (args[1] && !value_get_as_bool (args[1], NULL))
+	if (args[1] && !value_get_as_checked_bool (args[1]))
 		convs = gnm_expr_conventions_r1c1;
 
 	expr = gnm_expr_parse_str (text,
@@ -1283,7 +1283,7 @@ GnmFuncDescriptor const lookup_functions[] = {
 	{ "columns",   "A",    N_("ref"),
 	  help_columns, gnumeric_columns, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-	{ "hlookup",   "BAf|bb", N_("val,range,col_idx,approx,as_index"),
+	{ "hlookup",   "EAf|bb", N_("val,range,col_idx,approx,as_index"),
 	  help_hlookup, gnumeric_hlookup, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "hyperlink", "s|s", N_("link_location, label"),
@@ -1295,10 +1295,10 @@ GnmFuncDescriptor const lookup_functions[] = {
 	{ "index",     "A|fff",N_("reference,row,col,area"),
 	  help_index,    NULL, gnumeric_index, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-	{ "lookup",    "BA|r", N_("val,range,range"),
+	{ "lookup",    "EA|r", N_("val,range,range"),
 	  help_lookup,   gnumeric_lookup, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-	{ "match",     "BA|f", N_("val,range,approx"),
+	{ "match",     "EA|f", N_("val,range,approx"),
 	  help_match,    gnumeric_match, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "offset",    "rff|ff",N_("ref,row,col,height,width"),
@@ -1313,7 +1313,7 @@ GnmFuncDescriptor const lookup_functions[] = {
 	{ "transpose", "A",    N_("array"),
 	  help_transpose, gnumeric_transpose, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_RETURNS_NON_SCALAR, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-	{ "vlookup",   "BAf|bb", N_("val,range,col_idx,approx,as_index"),
+	{ "vlookup",   "EAf|bb", N_("val,range,col_idx,approx,as_index"),
 	  help_vlookup, gnumeric_vlookup, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 
