@@ -19,14 +19,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <gnome.h>
 #include <gnumeric-config.h>
 #include <gnumeric.h>
 #include "boot.h"
 #include "html.h"
 #include "latex.h"
 #include "roff.h"
-#include "file.h"
-#include "module-plugin-defs.h"
+#include <goffice/app/file.h>
+#include <gnm-plugin.h>
 
-GNUMERIC_MODULE_PLUGIN_INFO_DECL;
+GNM_PLUGIN_MODULE_HEADER;
