@@ -26,7 +26,7 @@
 
 #include <gnumeric-config.h>
 #include <gnumeric.h>
-#include "io-context.h"
+#include <goffice/app/io-context.h>
 #include "workbook-view.h"
 #include "workbook.h"
 #include "sheet-style.h"
@@ -39,11 +39,11 @@
 #include "sheet-merge.h"
 #include "value.h"
 #include "font.h"
-#include "plugin-util.h"
-#include "error-info.h"
+#include <goffice/app/error-info.h>
 #include "style-border.h"
 #include <rendered-value.h>
 #include "mstyle.h"
+#include "hlink.h"
 
 #include <gsf/gsf-output.h>
 #include <string.h>
@@ -91,6 +91,16 @@ html_print_encoded (GsfOutput *output, char const *str)
 			case '\"':
 				gsf_output_puts (output, "&quot;");
 				break;
+			case '\n':
+				gsf_output_puts (output, "<br>\n");
+				break;
+			case '\r':
+				gsf_output_puts (output, "<br>\r");
+				if( *(str+1) == '\n' ) {
+					gsf_output_puts (output, "\n");
+					str++;
+				}
+				break;
 			default:
 				c = g_utf8_get_char (str);
 				if (((c >= 0x20) && (c < 0x80)) ||
@@ -103,64 +113,58 @@ html_print_encoded (GsfOutput *output, char const *str)
 	}
 }
 
-/*
- * html_get_color:
- *
- * @mstyle: the cellstyle
- * @t:      which color
- * @r:      red component
- * @g:      green component
- * @b:      blue component
- *
- * Determine rgb components
- *
- */
 static void
-html_get_text_color (Cell *cell, MStyle *mstyle, guint *r, guint *g, guint *b)
+html_get_text_color (GnmCell *cell, GnmStyle *mstyle, guint *r, guint *g, guint *b)
 {
-	const PangoColor *fore = cell_get_render_color (cell);
+	GOColor fore = cell_get_render_color (cell);
 
-	if (fore == NULL)
+	if (fore == 0)
 		*r = *g = *b = 0;
 	else {
-		*r = fore->red >> 8;
-		*g = fore->green >> 8;
-		*b = fore->blue >> 8;
+		*r = UINT_RGBA_R (fore);
+		*g = UINT_RGBA_G (fore);
+		*b = UINT_RGBA_B (fore);
 	}
 }
 static void
-html_get_color (MStyle *mstyle, MStyleElementType t, guint *r, guint *g, guint *b)
+html_get_back_color (GnmStyle *mstyle, guint *r, guint *g, guint *b)
 {
-	StyleColor *color;
-
-	color = mstyle_get_color (mstyle, t);
-
-	*r = color->color.red >> 8;
-	*g = color->color.green >> 8;
-	*b = color->color.blue >> 8;
+	GnmColor const *color = gnm_style_get_back_color (mstyle);
+	*r = color->gdk_color.red >> 8;
+	*g = color->gdk_color.green >> 8;
+	*b = color->gdk_color.blue >> 8;
 }
 
 static void
-html_write_cell_content (GsfOutput *output, Cell *cell, MStyle *mstyle, html_version_t version)
+html_write_cell_content (GsfOutput *output, GnmCell *cell, GnmStyle *mstyle, html_version_t version)
 {
 	guint r = 0;
 	guint g = 0;
 	guint b = 0;
 	char *rendered_string;
-	gboolean hidden = mstyle_get_content_hidden (mstyle);
+	gboolean hidden = gnm_style_get_content_hidden (mstyle);
+	GnmHLink* hlink = gnm_style_get_hlink (mstyle);
+	const guchar* hlink_target = NULL;
+
+	if (hlink && IS_GNM_HLINK_URL (hlink)) {
+		hlink_target = gnm_hlink_get_target (hlink);
+	}
 
 	if (version == HTML32 && hidden)
 		gsf_output_puts (output, "<!-- 'HIDDEN DATA' -->");
 	else {
 		if (mstyle != NULL) {
-			if (mstyle_get_font_italic (mstyle))
+			if (gnm_style_get_font_italic (mstyle))
 				gsf_output_puts (output, "<i>");
-			if (mstyle_get_font_bold (mstyle))
+			if (gnm_style_get_font_bold (mstyle))
 				gsf_output_puts (output, "<b>");
 			if (font_is_monospaced (mstyle))
 				gsf_output_puts (output, "<tt>");
 		}
 
+		if (hlink_target)
+			gsf_output_printf (output, "<a href=\"%s\">", hlink_target);
+
 		if (cell != NULL) {
 			if (mstyle != NULL && version != HTML40) {
 				html_get_text_color (cell, mstyle, &r, &g, &b);
@@ -175,19 +179,21 @@ html_write_cell_content (GsfOutput *output, Cell *cell, MStyle *mstyle, html_ver
 
 		if (r > 0 || g > 0 || b > 0)
 			gsf_output_puts (output, "</font>");
+		if (hlink_target)
+			gsf_output_puts (output, "</a>");
 		if (mstyle != NULL) {
 			if (font_is_monospaced (mstyle))
 				gsf_output_puts (output, "</tt>");
-			if (mstyle_get_font_bold (mstyle))
+			if (gnm_style_get_font_bold (mstyle))
 				gsf_output_puts (output, "</b>");
-			if (mstyle_get_font_italic (mstyle))
+			if (gnm_style_get_font_italic (mstyle))
 				gsf_output_puts (output, "</i>");
 		}
 	}
 }
 
 static char *
-html_get_border_style (StyleBorder *border)
+html_get_border_style (GnmBorder *border)
 {
 	GString *text = g_string_new (NULL);
 	char *result;
@@ -238,9 +244,9 @@ html_get_border_style (StyleBorder *border)
 
 	if (border->color) {
 		guint r, g, b;
-		r = border->color->color.red >> 8;
-		g = border->color->color.green >> 8;
-		b = border->color->color.blue >> 8;
+		r = border->color->gdk_color.red >> 8;
+		g = border->color->gdk_color.green >> 8;
+		b = border->color->gdk_color.blue >> 8;
 		g_string_append_printf (text, " #%02X%02X%02X", r, g, b);
 	}
 
@@ -250,7 +256,7 @@ html_get_border_style (StyleBorder *border)
 }
 
 static void
-html_write_one_border_style_40 (GsfOutput *output, StyleBorder *border, char const *border_name)
+html_write_one_border_style_40 (GsfOutput *output, GnmBorder *border, char const *border_name)
 {
 	char *text;
 	text = html_get_border_style (border);
@@ -261,20 +267,20 @@ html_write_one_border_style_40 (GsfOutput *output, StyleBorder *border, char con
 }
 
 static void
-html_write_border_style_40 (GsfOutput *output, MStyle *mstyle)
+html_write_border_style_40 (GsfOutput *output, GnmStyle *mstyle)
 {
-	StyleBorder *border;
+	GnmBorder *border;
 
-	border = mstyle_get_border (mstyle, MSTYLE_BORDER_TOP);
+	border = gnm_style_get_border (mstyle, MSTYLE_BORDER_TOP);
 	if (!style_border_is_blank (border))
 		html_write_one_border_style_40 (output, border, "border-top");
-	border = mstyle_get_border (mstyle, MSTYLE_BORDER_BOTTOM);
+	border = gnm_style_get_border (mstyle, MSTYLE_BORDER_BOTTOM);
 	if (!style_border_is_blank (border))
 		html_write_one_border_style_40 (output, border, "border-bottom");
-	border = mstyle_get_border (mstyle, MSTYLE_BORDER_LEFT);
+	border = gnm_style_get_border (mstyle, MSTYLE_BORDER_LEFT);
 	if (!style_border_is_blank (border))
 		html_write_one_border_style_40 (output, border, "border-left");
-	border = mstyle_get_border (mstyle, MSTYLE_BORDER_RIGHT);
+	border = gnm_style_get_border (mstyle, MSTYLE_BORDER_RIGHT);
 	if (!style_border_is_blank (border))
 		html_write_one_border_style_40 (output, border, "border-right");
 }
@@ -282,22 +288,22 @@ html_write_border_style_40 (GsfOutput *output, MStyle *mstyle)
 static void
 write_cell (GsfOutput *output, Sheet *sheet, gint row, gint col, html_version_t version)
 {
-	Cell *cell;
-	MStyle *mstyle;
+	GnmCell *cell;
+	GnmStyle *mstyle;
 	guint r, g, b;
 
 	mstyle = sheet_style_get (sheet, col, row);
 	if (mstyle != NULL && version != HTML32 && version != HTML40 &&
-	    mstyle_get_pattern (mstyle) != 0 &&
-	    mstyle_is_element_set (mstyle, MSTYLE_COLOR_BACK)) {
-		html_get_color (mstyle, MSTYLE_COLOR_BACK, &r, &g, &b);
+	    gnm_style_get_pattern (mstyle) != 0 &&
+	    gnm_style_is_element_set (mstyle, MSTYLE_COLOR_BACK)) {
+		html_get_back_color (mstyle, &r, &g, &b);
 		gsf_output_printf (output, " bgcolor=\"#%02X%02X%02X\"", r, g, b);
 	}
 
 	cell = sheet_cell_get (sheet, col, row);
 	if (cell != NULL) {
 
-		switch (mstyle_get_align_v (mstyle)) {
+		switch (gnm_style_get_align_v (mstyle)) {
 		case VALIGN_TOP:
 			gsf_output_puts (output, " valign=\"top\" ");
 			break;
@@ -308,6 +314,7 @@ write_cell (GsfOutput *output, Sheet *sheet, gint row, gint col, html_version_t
 			gsf_output_puts (output, " valign=\"center\" ");
 			break;
 		case VALIGN_JUSTIFY:
+		case VALIGN_DISTRIBUTED:
 			gsf_output_puts (output, " valign=\"baseline\" ");
 			break;
 		default:
@@ -335,18 +342,18 @@ write_cell (GsfOutput *output, Sheet *sheet, gint row, gint col, html_version_t
 	if (version == HTML40 || version == HTML40F) {
 		if (mstyle != NULL) {
 			gsf_output_printf (output, " style=\"");
-			if (mstyle_get_pattern (mstyle) != 0 &&
-			    mstyle_is_element_set (mstyle, MSTYLE_COLOR_BACK)) {
-				html_get_color (mstyle, MSTYLE_COLOR_BACK, &r, &g, &b);
+			if (gnm_style_get_pattern (mstyle) != 0 &&
+			    gnm_style_is_element_set (mstyle, MSTYLE_COLOR_BACK)) {
+				html_get_back_color (mstyle, &r, &g, &b);
 				gsf_output_printf (output, "background:#%02X%02X%02X;", r, g, b);
 			}
 			if (cell != NULL) {
-				gint size = (int) (mstyle_get_font_size (mstyle) + 0.5);
+				gint size = (int) (gnm_style_get_font_size (mstyle) + 0.5);
 				gsf_output_printf (output, " font-size:%ipt;", size);
 				html_get_text_color (cell, mstyle, &r, &g, &b);
 				if (r > 0 || g > 0 || b > 0)
 					gsf_output_printf (output, " color:#%02X%02X%02X;", r, g, b);
-				if (mstyle_get_content_hidden (mstyle))
+				if (gnm_style_get_content_hidden (mstyle))
 					gsf_output_puts (output, " visibility:hidden;");
 			}
 
@@ -463,7 +470,7 @@ write_sheet (GsfOutput *output, Sheet *sheet,
  * write the html file (version of html according to version argument)
  */
 static void
-html_file_save (GnmFileSaver const *fs, IOContext *io_context,
+html_file_save (GOFileSaver const *fs, IOContext *io_context,
 		WorkbookView const *wb_view, GsfOutput *output, html_version_t version)
 {
 	GList *sheets, *ptr;
@@ -522,7 +529,6 @@ html_file_save (GnmFileSaver const *fs, IOContext *io_context,
 		break;
 	case XHTML  :
 		gsf_output_puts (output,
-"<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
 "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\"\n"
 "\t\t\"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">\n"
 "<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"en\" lang=\"en\">\n"
@@ -549,7 +555,7 @@ html_file_save (GnmFileSaver const *fs, IOContext *io_context,
 	}
 
 	sheets = workbook_sheets (wb);
-	save_scope = gnm_file_saver_get_save_scope (fs);
+	save_scope = go_file_saver_get_save_scope (fs);
 	for (ptr = sheets ; ptr != NULL ; ptr = ptr->next) {
 		write_sheet (output, (Sheet *) ptr->data, version, save_scope);
 	}
@@ -559,35 +565,35 @@ html_file_save (GnmFileSaver const *fs, IOContext *io_context,
 }
 
 void
-html40_file_save (GnmFileSaver const *fs, IOContext *io_context,
+html40_file_save (GOFileSaver const *fs, IOContext *io_context,
                   WorkbookView const *wb_view, GsfOutput *output)
 {
 	html_file_save (fs, io_context, wb_view, output, HTML40);
 }
 
 void
-html32_file_save (GnmFileSaver const *fs, IOContext *io_context,
+html32_file_save (GOFileSaver const *fs, IOContext *io_context,
                   WorkbookView const *wb_view, GsfOutput *output)
 {
 	html_file_save (fs, io_context, wb_view, output, HTML32);
 }
 
 void
-html40frag_file_save (GnmFileSaver const *fs, IOContext *io_context,
+html40frag_file_save (GOFileSaver const *fs, IOContext *io_context,
 		      WorkbookView const *wb_view, GsfOutput *output)
 {
 	html_file_save (fs, io_context, wb_view, output, HTML40F);
 }
 
 void
-xhtml_file_save (GnmFileSaver const *fs, IOContext *io_context,
+xhtml_file_save (GOFileSaver const *fs, IOContext *io_context,
 		 WorkbookView const *wb_view, GsfOutput *output)
 {
 	html_file_save (fs, io_context, wb_view, output, XHTML);
 }
 
 void
-xhtml_range_file_save (GnmFileSaver const *fs, IOContext *io_context,
+xhtml_range_file_save (GOFileSaver const *fs, IOContext *io_context,
 		      WorkbookView const *wb_view, GsfOutput *output)
 {
 	/* Identical, but fs->save_scope is different */
