@@ -40,9 +40,12 @@
 #include <sheet-merge.h>
 #include <sheet-style.h>
 #include <style.h>
+#include <style-color.h>
+#include <hlink.h>
 #include <cell.h>
 #include <ranges.h>
-#include <io-context.h>
+#include <goffice/app/io-context.h>
+#include <goffice/app/error-info.h>
 
 #include <gsf/gsf-input.h>
 #include <libxml/HTMLparser.h>
@@ -67,10 +70,10 @@ html_get_sheet (char const *name, Workbook *wb)
 		sheet = workbook_sheet_by_name (wb, name);
 		if (sheet == NULL) {
 			sheet = sheet_new (wb, name);
-			workbook_sheet_attach (wb, sheet, NULL);
+			workbook_sheet_attach (wb, sheet);
 		}
 	} else
-		sheet = workbook_sheet_add (wb, NULL, FALSE);
+		sheet = workbook_sheet_add (wb, -1, FALSE);
 	return sheet;
 }
 
@@ -80,10 +83,12 @@ html_append_text (GString *buf, const xmlChar *text)
 	const xmlChar *p;
 	
 	while (*text) {
-		while (g_ascii_isspace (*text))
-			text++;
+		while (g_unichar_isspace (g_utf8_get_char (text)))
+			text = g_utf8_next_char (text);
 		if (*text) {
-			for (p = text; *p && !g_ascii_isspace (*p); p++)
+			for (p = text; 
+			     *p && !g_unichar_isspace (g_utf8_get_char (p)); 
+			     p =  g_utf8_next_char (p))
 				;
 			if (buf->len > 0)
 				g_string_append_c (buf, ' ');
@@ -95,7 +100,8 @@ html_append_text (GString *buf, const xmlChar *text)
 
 static void
 html_read_content (htmlNodePtr cur, GString *buf, GnmStyle *mstyle,
-		   xmlBufferPtr a_buf, gboolean first, htmlDocPtr doc)
+		   xmlBufferPtr a_buf, GSList **hrefs, gboolean first, 
+		   htmlDocPtr doc)
 {
 	htmlNodePtr ptr;
 
@@ -107,17 +113,18 @@ html_read_content (htmlNodePtr cur, GString *buf, GnmStyle *mstyle,
 			if (first) {
 				if (xmlStrEqual (ptr->name, CC2XML ("i"))
 				    || xmlStrEqual (ptr->name, CC2XML ("em")))
-					mstyle_set_font_italic (mstyle, TRUE);
+					gnm_style_set_font_italic (mstyle, TRUE);
 				if (xmlStrEqual (ptr->name, CC2XML ("b")))
-					mstyle_set_font_bold (mstyle, TRUE);
+					gnm_style_set_font_bold (mstyle, TRUE);
 			}
 			if (xmlStrEqual (ptr->name, CC2XML ("a"))) {
 				xmlAttrPtr   props;
 				props = ptr->properties;
 				while (props) {
 					if (xmlStrEqual (props->name, CC2XML ("href")) && props->children) {
-						htmlNodeDump (a_buf, doc, props->children);
-						xmlBufferAdd (a_buf, CC2XML ("\n"), -1);
+						*hrefs = g_slist_prepend (
+							*hrefs, props->children);
+
 					}
 					props = props->next;
 				}
@@ -133,7 +140,8 @@ html_read_content (htmlNodePtr cur, GString *buf, GnmStyle *mstyle,
 					props = props->next;
 				}
 			}
-			html_read_content (ptr, buf, mstyle, a_buf, first, doc);
+			html_read_content (
+				ptr, buf, mstyle, a_buf, hrefs, first, doc);
 		}
 		first = FALSE;
 	}
@@ -155,6 +163,8 @@ html_read_row (htmlNodePtr cur, htmlDocPtr doc, GnmHtmlTableCtxt *tc)
 			int rowspan = 1;
 			GnmCellPos pos;
 			GnmStyle *mstyle;
+			GSList *hrefs = NULL;
+			GnmHLink *link = NULL;
 
 			/* Check whether we need to skip merges from above */
 			pos.row = tc->row;
@@ -182,18 +192,63 @@ html_read_row (htmlNodePtr cur, htmlDocPtr doc, GnmHtmlTableCtxt *tc)
 			buf = g_string_new (NULL);
 			a_buf = xmlBufferCreate ();
 
-			mstyle = mstyle_new_default ();
+			mstyle = gnm_style_new_default ();
 			if (xmlStrEqual (ptr->name, CC2XML ("th")))
-				mstyle_set_font_bold (mstyle, TRUE);
+				gnm_style_set_font_bold (mstyle, TRUE);
 
-			html_read_content (ptr, buf, mstyle, a_buf, TRUE, doc);
+			html_read_content (ptr, buf, mstyle, a_buf, 
+					   &hrefs, TRUE, doc);
 
+	
+			if (g_slist_length (hrefs) == 1 &&
+			    buf->len > 0) {
+				/* One hyperlink, and text to make it 
+				 * visible */
+				char *url;
+				xmlBufferPtr h_buf = xmlBufferCreate ();
+				
+				htmlNodeDump (
+					h_buf, doc, (htmlNodePtr)hrefs->data);
+				url = g_strndup (
+					CXML2C (h_buf->content), h_buf->use);
+				if (strncmp (url, "mailto:", 
+					     strlen ("mailto:")) == 0)
+					link = g_object_new (
+						gnm_hlink_email_get_type (),
+						NULL);
+				else
+					link = g_object_new (
+						gnm_hlink_url_get_type (), 
+						NULL);
+				gnm_hlink_set_target (link, url);
+				gnm_style_set_hlink (mstyle, link);
+				gnm_style_set_font_uline (
+					mstyle, UNDERLINE_SINGLE);
+				gnm_style_set_font_color (mstyle,
+					style_color_new_name ("blue"));
+				g_free (url);
+				xmlBufferFree (h_buf);
+			} else if (hrefs) {
+				/* Multiple links, no way to choose one, 
+				 * or no text to give hyperlink style,
+				 * so put them in a comment */
+				GSList *l;
+
+				hrefs = g_slist_reverse (hrefs);
+				for (l = hrefs; l != NULL; l = l->next) {
+					htmlNodeDump (a_buf, doc, 
+						      (htmlNodePtr)l->data);
+					xmlBufferAdd (a_buf, CC2XML ("\n"), 
+						      -1);
+				}
+			}
+			g_slist_free (hrefs);
 			if (buf->len > 0) {
 				GnmCell *cell = sheet_cell_fetch (tc->sheet, col + 1, tc->row);
 				sheet_style_set_pos (tc->sheet, col + 1, tc->row, mstyle);
 				cell_set_text (cell, buf->str);
 			} else
-				mstyle_unref (mstyle);
+				gnm_style_unref (mstyle);
 
 			if (a_buf->use > 0) {
 				char *name;
@@ -408,7 +463,7 @@ html_search_for_tables (htmlNodePtr cur, htmlDocPtr doc,
 }
 
 void
-html_file_open (GnmFileOpener const *fo, IOContext *io_context,
+html_file_open (GOFileOpener const *fo, IOContext *io_context,
 		WorkbookView *wb_view, GsfInput *input)
 {
 	guint8 const *buf;
@@ -421,49 +476,60 @@ html_file_open (GnmFileOpener const *fo, IOContext *io_context,
 
 	g_return_if_fail (input != NULL);
 
-	size = gsf_input_size (input) - 4;
-	buf = gsf_input_read (input, 4, NULL);
-	if (buf != NULL) {
-		enc = xmlDetectCharEncoding(buf, 4);
-		switch (enc) {	/* Skip byte order mark */
-		case XML_CHAR_ENCODING_UCS4BE:
-		case XML_CHAR_ENCODING_UCS4LE:
-		case XML_CHAR_ENCODING_UCS4_2143:
-		case XML_CHAR_ENCODING_UCS4_3412:
-		case XML_CHAR_ENCODING_EBCDIC:
-			bomlen = 4;
-			break;
-		case XML_CHAR_ENCODING_UTF16BE:
-		case XML_CHAR_ENCODING_UTF16LE:
-			bomlen = 2;
-			break;
-		case XML_CHAR_ENCODING_UTF8:
-			if (buf[0] == 0xef)
-				bomlen = 3;
-			else if (buf[0] == 0x3c)
+	size = gsf_input_size (input);
+	if (size >= 4) {
+		size -= 4;
+		buf = gsf_input_read (input, 4, NULL);
+		if (buf != NULL) {
+			enc = xmlDetectCharEncoding(buf, 4);
+			switch (enc) {	/* Skip byte order mark */
+			case XML_CHAR_ENCODING_UCS4BE:
+			case XML_CHAR_ENCODING_UCS4LE:
+			case XML_CHAR_ENCODING_UCS4_2143:
+			case XML_CHAR_ENCODING_UCS4_3412:
+			case XML_CHAR_ENCODING_EBCDIC:
 				bomlen = 4;
-			else
-				bomlen = 0;
-			break;
-		default:
-			bomlen = 0;
-		}
-		ctxt = htmlCreatePushParserCtxt (NULL, NULL,
-						 (const char *)(buf + bomlen),
-						 4 - bomlen,
-						 gsf_input_name (input), enc);
-
-		for (; size > 0 ; size -= len) {
-			len = MIN (4096, size);
-			buf = gsf_input_read (input, len, NULL);
-			if (buf == NULL)
 				break;
-			htmlParseChunk (ctxt, (const char *)buf, len, 0);
-		}
+			case XML_CHAR_ENCODING_UTF16BE:
+			case XML_CHAR_ENCODING_UTF16LE:
+				bomlen = 2;
+				break;
+			case XML_CHAR_ENCODING_UTF8:
+				if (buf[0] == 0xef)
+					bomlen = 3;
+				else if (buf[0] == 0x3c)
+					bomlen = 4;
+				else
+					bomlen = 0;
+				break;
+			case XML_CHAR_ENCODING_NONE:
+				bomlen = 0;
+				/* Try to detect unmarked UTF16LE 
+				   (Firefox drag data) */
+				if (buf[0] >= 0x20 && buf[1] == 0 && 
+				    buf[2] >= 0x20 && buf[3] == 0)
+					enc =  XML_CHAR_ENCODING_UTF16LE;
+				break;
+			default:
+				bomlen = 0;
+			}
+			ctxt = htmlCreatePushParserCtxt (
+				NULL, NULL, (const char *)(buf + bomlen),
+				4 - bomlen, gsf_input_name (input), enc);
+			
+			for (; size > 0 ; size -= len) {
+				len = MIN (4096, size);
+				buf = gsf_input_read (input, len, NULL);
+				if (buf == NULL)
+					break;
+				htmlParseChunk (
+					ctxt, (const char *)buf, len, 0);
+			}
 
-		htmlParseChunk (ctxt, (const char *)buf, 0, 1);
-		doc = ctxt->myDoc;
-		htmlFreeParserCtxt (ctxt);
+			htmlParseChunk (ctxt, (const char *)buf, 0, 1);
+			doc = ctxt->myDoc;
+			htmlFreeParserCtxt (ctxt);
+		}
 	}
 
 	if (doc != NULL) {
