@@ -23,30 +23,28 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
+#include "mps.h"
 #include <gnumeric.h>
-#include <sys/types.h>
-#include <sys/mman.h>
-#include <unistd.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
 #include "cell.h"
 #include "sheet.h"
 #include "value.h"
-#include "file.h"
-#include "io-context.h"
+#include <goffice/app/io-context.h>
 #include "workbook-view.h"
 #include "workbook.h"
-#include "plugin-util.h"
-#include "module-plugin-defs.h"
+#include <goffice/app/module-plugin-defs.h>
 #include "ranges.h"
 #include "style.h"
 #include "value.h"
 #include "solver.h"
 #include "sheet-style.h"
 #include "parse-util.h"
-#include "mps.h"
+#include <goffice/app/file.h>
+#include <goffice/app/error-info.h>
+#include <glib/gi18n.h>
+#include <sys/types.h>
+#include <unistd.h>
+#include <stdlib.h>
+#include <string.h>
 
 
 /************************************************************************
