@@ -843,6 +843,6 @@ go_plugin_loader_init (GOPluginLoaderClass *iface)
 }
 
 GSF_DYNAMIC_CLASS_FULL (GnmPythonPluginLoader, gnm_python_plugin_loader,
-	gplp_class_init, gplp_init,
-	G_TYPE_OBJECT, 0,
+	NULL, NULL, gplp_class_init, NULL,
+	gplp_init, G_TYPE_OBJECT, 0,
 	GSF_INTERFACE_FULL (gnm_python_plugin_loader_type, go_plugin_loader_init, GO_PLUGIN_LOADER_TYPE))
