@@ -7,6 +7,7 @@
 typedef enum {
 	COLLECT_IGNORE_STRINGS	= 0x01,
 	COLLECT_ZERO_STRINGS	= 0x02,
+	COLLECT_COERCE_STRINGS	= 0x04,
 
 	COLLECT_IGNORE_BOOLS	= 0x10,
 	COLLECT_ZEROONE_BOOLS	= 0x20,
@@ -16,7 +17,6 @@ typedef enum {
 
 	COLLECT_IGNORE_BLANKS	= 0x1000,
 	COLLECT_IGNORE_SUBTOTAL	= 0x2000,
-	COLLECT_DATES		= 0x4000,
 	COLLECT_INFO		= 0x8000,
 
 	COLLECT_NO_INFO_MASK	= 0x7777
