@@ -19,7 +19,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include <gnumeric.h>
 #include "dialogs.h"
 #include "help.h"
@@ -30,7 +30,6 @@
 #include <sheet-object-cell-comment.h>
 #include <workbook-edit.h>
 #include <ranges.h>
-#include <gtk/gtk.h>
 #include <commands.h>
 
 #define COMMENT_DIALOG_KEY "cell-comment-dialog"
@@ -38,7 +37,7 @@
 typedef struct {
 	WorkbookControlGUI *wbcg;
 	Sheet              *sheet;
-	CellPos const      *pos;
+	GnmCellPos const      *pos;
 	GtkWidget          *dialog;
 	GtkWidget          *ok_button;
 	GtkWidget          *cancel_button;
@@ -90,11 +89,11 @@ cb_cell_comment_ok_clicked (G_GNUC_UNUSED GtkWidget *button,
 }
 
 void
-dialog_cell_comment (WorkbookControlGUI *wbcg, Sheet *sheet, CellPos const *pos)
+dialog_cell_comment (WorkbookControlGUI *wbcg, Sheet *sheet, GnmCellPos const *pos)
 {
 	CommentState	*state;
 	GtkWidget	*textview;
-	CellComment	*comment;
+	GnmComment	*comment;
 	GladeXML	*gui;
 
 	g_return_if_fail (wbcg != NULL);
@@ -103,7 +102,7 @@ dialog_cell_comment (WorkbookControlGUI *wbcg, Sheet *sheet, CellPos const *pos)
 
 	if (gnumeric_dialog_raise_if_exists (wbcg, COMMENT_DIALOG_KEY))
 		return;
-	gui = gnm_glade_xml_new (COMMAND_CONTEXT (wbcg),
+	gui = gnm_glade_xml_new (GO_CMD_CONTEXT (wbcg),
 		"cell-comment.glade", NULL, NULL);
 	if (gui == NULL)
 		return;
