@@ -95,8 +95,7 @@ csv_page_global_change (G_GNUC_UNUSED GtkWidget *widget,
 	trim = parseoptions->trim_spaces;	
 	stf_parse_options_set_trim_spaces (parseoptions, TRIM_TYPE_NEVER);
 	lines = stf_parse_general (parseoptions, lines_chunk,
-				   pagedata->cur, pagedata->cur_end,
-				   LINE_DISPLAY_LIMIT);
+				   pagedata->cur, pagedata->cur_end);
 	stf_parse_options_set_trim_spaces (parseoptions, trim);
 
 	stf_preview_set_lines (renderdata, lines_chunk, lines);
