@@ -5,6 +5,7 @@
 #include "gnumeric.h"
 #include "summary.h"
 #include "workbook-control-gui.h"
+#include <goffice/graph/gog-style.h>
 
 typedef enum {
 	FD_CURRENT = -1,
@@ -31,6 +32,7 @@ void	 dialog_delete_cells	(WorkbookControlGUI *wbcg);
 void	 dialog_zoom		(WorkbookControlGUI *wbcg, Sheet *sheet);
 void	 dialog_about		(WorkbookControlGUI *wbcg);
 void	 dialog_define_names	(WorkbookControlGUI *wbcg);
+void	 dialog_paste_names	(WorkbookControlGUI *wbcg);
 void	 dialog_cell_comment	(WorkbookControlGUI *wbcg,
 				 Sheet *sheet, GnmCellPos const *pos);
 void	 dialog_cell_sort	(WorkbookControlGUI *wbcg);
@@ -104,9 +106,14 @@ int dialog_ttest_tool    (WorkbookControlGUI *wbcg, Sheet *sheet, ttest_type tes
 char *dialog_get_password (GtkWindow *parent, char const *filename);
 
 /* Modeless dialogs */
-void	 dialog_summary_update  (WorkbookControlGUI *wbcg, gboolean open_dialogs);
-void     dialog_preferences (WorkbookControlGUI *wbcg, gint page);
+void	dialog_summary_update  (WorkbookControlGUI *wbcg, gboolean open_dialogs);
+void	dialog_preferences (WorkbookControlGUI *wbcg, gint page);
 
-void     dialog_new_view (WorkbookControlGUI *wbcg);
+void	dialog_new_view (WorkbookControlGUI *wbcg);
+void	dialog_so_styled (WorkbookControlGUI *wbcg, GObject *so,
+			  GogStyle *orig, GogStyle *default_style,
+			  char const *title);
+
+void	dialog_doc_metadata_new  (WorkbookControlGUI *wbcg);
 
 #endif /* GNUMERIC_DIALOGS_H */
