@@ -70,6 +70,8 @@ gboolean  gnm_expr_is_rangeref 	     (GnmExpr const *expr);
 GnmExprArray const *
 	  gnm_expr_is_array 	     (GnmExpr const *expr);
 gboolean  gnm_expr_is_err 	     (GnmExpr const *expr, GnmStdError e);
+gboolean  gnm_expr_is_data_table     (GnmExpr const *expr,
+				      GnmCellPos *c_in, GnmCellPos *r_in);
 gboolean  gnm_expr_equal	     (GnmExpr const *a, GnmExpr const *b);
 char	 *gnm_expr_as_string	     (GnmExpr const *expr, GnmParsePos const *pp,
 				      GnmExprConventions const *fmt);
@@ -83,23 +85,26 @@ gboolean  gnm_expr_containts_subtotal(GnmExpr const *expr);
 struct _GnmExprRelocateInfo {
 	GnmEvalPos pos;
 
-	GnmRange   origin;	        /* References to cells in origin_sheet!range */
-	Sheet  *origin_sheet;	/* should to adjusted */
-
-	Sheet  *target_sheet;	/* to point at this sheet */
-	int col_offset, row_offset;/* and offset by this amount */
+	GnmRange   origin;	    /* References to cells in origin_sheet!range */
+	Sheet     *origin_sheet;    /* should to adjusted */
+	Sheet     *target_sheet;    /* to point at this sheet */
+	int col_offset, row_offset; /* and offset by this amount */
 	enum {
-		GNM_EXPR_RELOCATE_STD = 0,	/* do standard relocation */
-		GNM_EXPR_RELOCATE_NAME_COL = 0x1, /* col ins/del */
-		GNM_EXPR_RELOCATE_NAME_ROW = 0x2  /* row ins/del */
-	} type;
+		GNM_EXPR_RELOCATE_STD,	/* do standard relocation */
+		GNM_EXPR_RELOCATE_COLS, /* ins/del col */
+		GNM_EXPR_RELOCATE_ROWS	/* ins/del row */
+	} reloc_type;
 };
 
 struct _GnmExprRewriteInfo {
 	enum {
+		/* invalidate references to specified sheet */
 		GNM_EXPR_REWRITE_INVALIDATE_SHEETS,
-		GNM_EXPR_REWRITE_RELOCATE
-	} type;
+		/* relocate only fully absolute references */
+		GNM_EXPR_REWRITE_NAME,
+		/* relocate all references */
+		GNM_EXPR_REWRITE_EXPR
+	} rw_type;
 
 	union {
 		struct {
@@ -117,10 +122,10 @@ GnmValue *gnm_expr_eval (GnmExpr const *expr, GnmEvalPos const *pos,
 
 /*****************************************************************************/
 
-#define gnm_expr_list_nth(l,n)	   (GnmExpr const *)g_slist_nth_data ((l), n)
 #define gnm_expr_list_append(l,e)  g_slist_append ((l), (gpointer)(e))
 #define gnm_expr_list_prepend(l,e) g_slist_prepend ((l), (gpointer)(e))
 #define gnm_expr_list_length(l)	   g_slist_length((GSList *)(l)) /* const cast */
+#define gnm_expr_list_nth(l,n)	   (GnmExpr const *)g_slist_nth_data ((GSList *)(l), n) /* const cast */
 #define gnm_expr_list_free	   g_slist_free
 void 	 gnm_expr_list_unref	  (GnmExprList *list);
 gboolean gnm_expr_list_equal	  (GnmExprList const *a, GnmExprList const *b);
