@@ -97,7 +97,7 @@ format_template_member_clone (TemplateMember *member)
 	clone->skip      = member->skip;
 	clone->edge      = member->edge;
 	clone->mstyle    = member->mstyle;
-	mstyle_ref (member->mstyle);
+	gnm_style_ref (member->mstyle);
 
 	return clone;
 }
@@ -114,7 +114,7 @@ format_template_member_free (TemplateMember *member)
 	g_return_if_fail (member != NULL);
 
 	if (member->mstyle) {
-		mstyle_unref (member->mstyle);
+		gnm_style_unref (member->mstyle);
 		member->mstyle = NULL;
 	}
 
@@ -183,6 +183,8 @@ format_template_member_get_rect (TemplateMember const *member, GnmRange const *r
 			res.start.col = r->start.col - member->col.size;
 	}
 
+	range_is_sane (&res);
+
 	return res;
 }
 
@@ -263,7 +265,7 @@ format_template_new (void)
 	ft->edges.top    = TRUE;
 	ft->edges.bottom = TRUE;
 
-	ft->table     = g_hash_table_new_full (NULL, NULL, NULL, (GDestroyNotify)mstyle_unref);
+	ft->table     = g_hash_table_new_full (NULL, NULL, NULL, (GDestroyNotify)gnm_style_unref);
 	ft->invalidate_hash = TRUE;
 
 	range_init (&ft->dimension, 0,0,0,0);
@@ -657,74 +659,74 @@ format_template_filter_style (FormatTemplate *ft, GnmStyle *mstyle, gboolean fil
 	 */
 	if (!fill_defaults) {
 		if (!ft->number) {
-			mstyle_unset_element (mstyle, MSTYLE_FORMAT);
+			gnm_style_unset_element (mstyle, MSTYLE_FORMAT);
 		}
 		if (!ft->border) {
-			mstyle_unset_element (mstyle, MSTYLE_BORDER_TOP);
-			mstyle_unset_element (mstyle, MSTYLE_BORDER_BOTTOM);
-			mstyle_unset_element (mstyle, MSTYLE_BORDER_LEFT);
-			mstyle_unset_element (mstyle, MSTYLE_BORDER_RIGHT);
-			mstyle_unset_element (mstyle, MSTYLE_BORDER_DIAGONAL);
-			mstyle_unset_element (mstyle, MSTYLE_BORDER_REV_DIAGONAL);
+			gnm_style_unset_element (mstyle, MSTYLE_BORDER_TOP);
+			gnm_style_unset_element (mstyle, MSTYLE_BORDER_BOTTOM);
+			gnm_style_unset_element (mstyle, MSTYLE_BORDER_LEFT);
+			gnm_style_unset_element (mstyle, MSTYLE_BORDER_RIGHT);
+			gnm_style_unset_element (mstyle, MSTYLE_BORDER_DIAGONAL);
+			gnm_style_unset_element (mstyle, MSTYLE_BORDER_REV_DIAGONAL);
 		}
 		if (!ft->font) {
-			mstyle_unset_element (mstyle, MSTYLE_FONT_NAME);
-			mstyle_unset_element (mstyle, MSTYLE_FONT_BOLD);
-			mstyle_unset_element (mstyle, MSTYLE_FONT_ITALIC);
-			mstyle_unset_element (mstyle, MSTYLE_FONT_UNDERLINE);
-			mstyle_unset_element (mstyle, MSTYLE_FONT_STRIKETHROUGH);
-			mstyle_unset_element (mstyle, MSTYLE_FONT_SIZE);
+			gnm_style_unset_element (mstyle, MSTYLE_FONT_NAME);
+			gnm_style_unset_element (mstyle, MSTYLE_FONT_BOLD);
+			gnm_style_unset_element (mstyle, MSTYLE_FONT_ITALIC);
+			gnm_style_unset_element (mstyle, MSTYLE_FONT_UNDERLINE);
+			gnm_style_unset_element (mstyle, MSTYLE_FONT_STRIKETHROUGH);
+			gnm_style_unset_element (mstyle, MSTYLE_FONT_SIZE);
 
-			mstyle_unset_element (mstyle, MSTYLE_COLOR_FORE);
+			gnm_style_unset_element (mstyle, MSTYLE_FONT_COLOR);
 		}
 		if (!ft->patterns) {
-			mstyle_unset_element (mstyle, MSTYLE_COLOR_BACK);
-			mstyle_unset_element (mstyle, MSTYLE_COLOR_PATTERN);
-			mstyle_unset_element (mstyle, MSTYLE_PATTERN);
+			gnm_style_unset_element (mstyle, MSTYLE_COLOR_BACK);
+			gnm_style_unset_element (mstyle, MSTYLE_COLOR_PATTERN);
+			gnm_style_unset_element (mstyle, MSTYLE_PATTERN);
 		}
 		if (!ft->alignment) {
-			mstyle_unset_element (mstyle, MSTYLE_ALIGN_V);
-			mstyle_unset_element (mstyle, MSTYLE_ALIGN_H);
+			gnm_style_unset_element (mstyle, MSTYLE_ALIGN_V);
+			gnm_style_unset_element (mstyle, MSTYLE_ALIGN_H);
 		}
 	} else {
-		GnmStyle *mstyle_default = mstyle_new_default ();
+		GnmStyle *gnm_style_default = gnm_style_new_default ();
 
 		/*
 		 * We fill in the gaps with the default mstyle
 		 */
 
 		 if (!ft->number) {
-			 mstyle_replace_element (mstyle_default, mstyle, MSTYLE_FORMAT);
+			 gnm_style_merge_element (mstyle, gnm_style_default, MSTYLE_FORMAT);
 		 }
 		 if (!ft->border) {
-			 mstyle_replace_element (mstyle_default, mstyle, MSTYLE_BORDER_TOP);
-			 mstyle_replace_element (mstyle_default, mstyle, MSTYLE_BORDER_BOTTOM);
-			 mstyle_replace_element (mstyle_default, mstyle, MSTYLE_BORDER_LEFT);
-			 mstyle_replace_element (mstyle_default, mstyle, MSTYLE_BORDER_RIGHT);
-			 mstyle_replace_element (mstyle_default, mstyle, MSTYLE_BORDER_DIAGONAL);
-			 mstyle_replace_element (mstyle_default, mstyle, MSTYLE_BORDER_REV_DIAGONAL);
+			 gnm_style_merge_element (mstyle, gnm_style_default, MSTYLE_BORDER_TOP);
+			 gnm_style_merge_element (mstyle, gnm_style_default, MSTYLE_BORDER_BOTTOM);
+			 gnm_style_merge_element (mstyle, gnm_style_default, MSTYLE_BORDER_LEFT);
+			 gnm_style_merge_element (mstyle, gnm_style_default, MSTYLE_BORDER_RIGHT);
+			 gnm_style_merge_element (mstyle, gnm_style_default, MSTYLE_BORDER_DIAGONAL);
+			 gnm_style_merge_element (mstyle, gnm_style_default, MSTYLE_BORDER_REV_DIAGONAL);
 		 }
 		 if (!ft->font) {
-			 mstyle_replace_element (mstyle_default, mstyle, MSTYLE_FONT_NAME);
-			 mstyle_replace_element (mstyle_default, mstyle, MSTYLE_FONT_BOLD);
-			 mstyle_replace_element (mstyle_default, mstyle, MSTYLE_FONT_ITALIC);
-			 mstyle_replace_element (mstyle_default, mstyle, MSTYLE_FONT_UNDERLINE);
-			 mstyle_replace_element (mstyle_default, mstyle, MSTYLE_FONT_STRIKETHROUGH);
-			 mstyle_replace_element (mstyle_default, mstyle, MSTYLE_FONT_SIZE);
+			 gnm_style_merge_element (mstyle, gnm_style_default, MSTYLE_FONT_NAME);
+			 gnm_style_merge_element (mstyle, gnm_style_default, MSTYLE_FONT_BOLD);
+			 gnm_style_merge_element (mstyle, gnm_style_default, MSTYLE_FONT_ITALIC);
+			 gnm_style_merge_element (mstyle, gnm_style_default, MSTYLE_FONT_UNDERLINE);
+			 gnm_style_merge_element (mstyle, gnm_style_default, MSTYLE_FONT_STRIKETHROUGH);
+			 gnm_style_merge_element (mstyle, gnm_style_default, MSTYLE_FONT_SIZE);
 
-			 mstyle_replace_element (mstyle_default, mstyle, MSTYLE_COLOR_FORE);
+			 gnm_style_merge_element (mstyle, gnm_style_default, MSTYLE_FONT_COLOR);
 		 }
 		 if (!ft->patterns) {
-			 mstyle_replace_element (mstyle_default, mstyle, MSTYLE_COLOR_BACK);
-			 mstyle_replace_element (mstyle_default, mstyle, MSTYLE_COLOR_PATTERN);
-			 mstyle_replace_element (mstyle_default, mstyle, MSTYLE_PATTERN);
+			 gnm_style_merge_element (mstyle, gnm_style_default, MSTYLE_COLOR_BACK);
+			 gnm_style_merge_element (mstyle, gnm_style_default, MSTYLE_COLOR_PATTERN);
+			 gnm_style_merge_element (mstyle, gnm_style_default, MSTYLE_PATTERN);
 		 }
 		 if (!ft->alignment) {
-			 mstyle_replace_element (mstyle_default, mstyle, MSTYLE_ALIGN_V);
-			 mstyle_replace_element (mstyle_default, mstyle, MSTYLE_ALIGN_H);
+			 gnm_style_merge_element (mstyle, gnm_style_default, MSTYLE_ALIGN_V);
+			 gnm_style_merge_element (mstyle, gnm_style_default, MSTYLE_ALIGN_H);
 		 }
 
-		 mstyle_unref (mstyle_default);
+		 gnm_style_unref (gnm_style_default);
 	}
 
 	return mstyle;
@@ -750,16 +752,15 @@ static gboolean
 format_template_range_check (FormatTemplate *ft, GnmRange const *r,
 			     GOCmdContext *optional_cc)
 {
-	GSList *iterator;
+	GSList *ptr;
 	int diff_col_high = -1;
 	int diff_row_high = -1;
 	gboolean invalid_range_seen = FALSE;
 
 	g_return_val_if_fail (ft != NULL, FALSE);
 
-	iterator = ft->members;
-	while (iterator) {
-		TemplateMember *member = iterator->data;
+	for (ptr = ft->members; NULL != ptr ; ptr = ptr->next) {
+		TemplateMember *member = ptr->data;
 		GnmRange range = format_template_member_get_rect (member, r);
 
 		if (!range_valid (&range)) {
@@ -774,8 +775,6 @@ format_template_range_check (FormatTemplate *ft, GnmRange const *r,
 
 			invalid_range_seen = TRUE;
 		}
-
-		iterator = g_slist_next (iterator);
 	}
 
 	if (invalid_range_seen && optional_cc != NULL) {
@@ -808,92 +807,68 @@ format_template_range_check (FormatTemplate *ft, GnmRange const *r,
 	return !invalid_range_seen;
 }
 
-/**
- * format_template_transform_edges:
- * @ft: The template to transform
- *
- * Transforms a template by remove edge styles. This routine
- * will return a copy of @ft which should be freed by the
- * caller.
- *
- * Return value: A new tranformed format template
- **/
+/* Remove edge styles from a template and shift items that anchor on a filtered
+ * edge.  Returns a filtered copy of @origft. */
 static FormatTemplate *
-format_template_transform_edges (FormatTemplate const *origft)
+gnm_auto_fmt_filter_edges (FormatTemplate const *origft)
 {
-	FormatTemplate *ft;
-	GSList *ptr0, *ptr1, *next;
+	GSList *ptr;
+	FormatTemplate *ft = format_template_clone (origft);
+	TemplateMember *member;
+	gboolean is_edge, l = FALSE, r = FALSE, t = FALSE, b = FALSE;
 
-	g_return_val_if_fail (origft != NULL, NULL);
+	for (ptr = ft->members; ptr != NULL ; ) {
+		member = ptr->data;
+		ptr = ptr->next;
+		if (!member->direction == FREQ_DIRECTION_NONE)
+			continue;
 
-	ft = format_template_clone (origft);
-	for (ptr0 = ft->members; ptr0 != NULL ; ptr0 = next) {
-		TemplateMember *member = ptr0->data;
-
-		gboolean left   = FALSE;
-		gboolean right  = FALSE;
-		gboolean top    = FALSE;
-		gboolean bottom = FALSE;
-
-		next = ptr0->next; /* we may delete it later */
-
-		if (member->col.size == 1 &&
-		    member->direction == FREQ_DIRECTION_NONE) {
-			left   = (member->col.offset_gravity > 0
-				  && !ft->edges.left);
-			right  = (member->col.offset_gravity < 0
-				  && !ft->edges.right);
+		is_edge = FALSE;
+		if (member->col.size == 1) {
+			if (!ft->edges.left && member->col.offset_gravity > 0)
+				l |= (is_edge = TRUE);
+			if (!ft->edges.right && member->col.offset_gravity < 0)
+				r |= (is_edge = TRUE);
 		}
-		if (member->row.size == 1 &&
-		    member->direction == FREQ_DIRECTION_NONE) {
-			top    = (member->row.offset_gravity > 0
-				  && !ft->edges.top);
-			bottom = (member->row.offset_gravity < 0
-				  && !ft->edges.bottom);
+		if (member->row.size == 1) {
+			if (!ft->edges.top && member->row.offset_gravity > 0)
+				t |= (is_edge = TRUE);
+			if (!ft->edges.bottom && member->row.offset_gravity < 0)
+				b |= (is_edge = TRUE);
+		}
+		if (is_edge) {
+			format_template_member_free (member);
+			ft->members = g_slist_remove (ft->members, member);
+		}
+	}
+
+	if (!l && !r && !t && !b)
+		return ft;
+	for (ptr = ft->members; ptr != NULL ; ptr = ptr->next) {
+		TemplateMember *submember = ptr->data;
+
+		if (l && submember->col.offset_gravity > 0) {
+			if (submember->col.offset >= 1)
+				submember->col.offset--;
+			submember->edge = 0;
 		}
 
-		if (left || right || top || bottom) {
+		if (r && submember->col.offset_gravity < 0) {
+			if (submember->col.offset >= 1)
+				submember->col.offset--;
+			submember->edge = 0;
+		}
 
-			for (ptr1 = ft->members; ptr1 != NULL ; ptr1 = ptr1->next) {
-				TemplateMember *submember = ptr1->data;
+		if (t && submember->row.offset_gravity > 0) {
+			if (submember->row.offset >= 1)
+				submember->row.offset--;
+			submember->edge = 0;
+		}
 
-				if (left
-				    && submember->col.offset_gravity == member->col.offset_gravity) {
-					if (submember->direction != FREQ_DIRECTION_NONE) {
-						submember->edge = 0;
-						submember->col.offset--;
-					} else if (submember->col.offset == 1)
-						submember->col.offset = 0;
-				}
-
-				if (right
-				    && submember->col.offset_gravity == -member->col.offset_gravity) {
-					if (submember->col.size == -member->col.size)
-						submember->col.size = 0;
-					else if (submember->direction != FREQ_DIRECTION_NONE)
-						submember->edge = 0;
-				}
-
-				if (top
-				    && submember->row.offset_gravity == member->row.offset_gravity) {
-					if (submember->direction != FREQ_DIRECTION_NONE) {
-						submember->edge = 0;
-						submember->row.offset--;
-					} else if (submember->row.offset == 1)
-						submember->row.offset = 0;
-				}
-
-				if (bottom
-				    && submember->row.offset_gravity == -member->row.offset_gravity) {
-					if (submember->row.size == -member->row.size)
-						submember->row.size = 0;
-					else if (submember->direction != FREQ_DIRECTION_NONE)
-						submember->edge = 0;
-				}
-			}
-
-			format_template_member_free (ptr0->data);
-			ft->members = g_slist_remove (ft->members, ptr0->data);
+		if (b && submember->row.offset_gravity < 0) {
+			if (submember->row.offset >= 1)
+				submember->row.offset--;
+			submember->edge = 0;
 		}
 	}
 	return ft;
@@ -915,31 +890,27 @@ static void
 format_template_calculate (FormatTemplate *origft, GnmRange const *r, PCalcCallback pc, gpointer cb_data)
 {
 	FormatTemplate *ft = origft;
-	GSList *iterator;
+	GSList *ptr;
 
 	g_return_if_fail (origft != NULL);
 
 	if (!ft->edges.left || !ft->edges.right || !ft->edges.top || !ft->edges.bottom)
-		ft = format_template_transform_edges (origft);
+		ft = gnm_auto_fmt_filter_edges (origft);
 
-	/*
-	 * Apply all styles
-	 */
-	iterator = ft->members;
-	while (iterator) {
-		TemplateMember const *member = iterator->data;
+	for (ptr = ft->members; NULL != ptr ; ptr = ptr->next) {
+		TemplateMember const *member = ptr->data;
 		GnmStyle const *mstyle = member->mstyle;
 		GnmRange range = format_template_member_get_rect (member, r);
 
 		if (member->direction == FREQ_DIRECTION_NONE)
-			pc (ft, &range, mstyle_copy (mstyle), cb_data);
+			pc (ft, &range, gnm_style_dup (mstyle), cb_data);
 
 		else if (member->direction == FREQ_DIRECTION_HORIZONTAL) {
 			int col_repeat = member->repeat;
 			GnmRange hr = range;
 
 			while (col_repeat != 0) {
-				pc (ft, &hr, mstyle_copy (mstyle), cb_data);
+				pc (ft, &hr, gnm_style_dup (mstyle), cb_data);
 
 				hr.start.col += member->skip + member->col.size;
 				hr.end.col   += member->skip + member->col.size;
@@ -959,7 +930,7 @@ format_template_calculate (FormatTemplate *origft, GnmRange const *r, PCalcCallb
 			GnmRange vr = range;
 
 			while (row_repeat != 0) {
-				pc (ft, &vr, mstyle_copy (mstyle), cb_data);
+				pc (ft, &vr, gnm_style_dup (mstyle), cb_data);
 
 				vr.start.row += member->skip + member->row.size;
 				vr.end.row   += member->skip + member->row.size;
@@ -975,8 +946,6 @@ format_template_calculate (FormatTemplate *origft, GnmRange const *r, PCalcCallb
 					break;
 			}
 		}
-
-		iterator = g_slist_next (iterator);
 	}
 
 	if (ft != origft)
@@ -997,18 +966,16 @@ cb_format_hash_style (FormatTemplate *ft, GnmRange *r, GnmStyle *mstyle, GHashTa
 	 */
 	mstyle = format_template_filter_style (ft, mstyle, TRUE);
 
-	for (row = r->start.row; row <= r->end.row; row++) {
-		for (col = r->start.col; col <= r->end.col; col++) {
+	for (row = r->start.row; row <= r->end.row; row++)
+		for (col = r->start.col; col <= r->end.col; col++)
 			g_hash_table_insert (table, ROW_COL_KEY (row, col),
-					     mstyle_copy (mstyle));
-		}
-	}
+				gnm_style_dup (mstyle));
 
 	/*
 	 * Unref here, the hashtable will take care of its own
 	 * resources
 	 */
-	mstyle_unref (mstyle);
+	gnm_style_unref (mstyle);
 }
 
 /**
