@@ -52,6 +52,14 @@ typedef struct {
 /* The name of our clipboard atom and the 'magic' info number */
 #define GNUMERIC_ATOM_NAME "application/x-gnumeric"
 #define GNUMERIC_ATOM_INFO 2001
+#define GOFFICE_GRAPH_ATOM_NAME "application/x-goffice-graph"
+
+/* From MS Excel */
+#define BIFF8_ATOM_NAME	"Biff8"
+#define BIFF5_ATOM_NAME	"Biff5"
+#define BIFF4_ATOM_NAME	"Biff4"
+#define BIFF3_ATOM_NAME	"Biff3"
+#define BIFF_ATOM_NAME	"Biff"
 
 #define HTML_ATOM_NAME "text/html"
 #define OOO_ATOM_NAME "application/x-openoffice;windows_formatname=\"Star Embed Source (XML)\""
@@ -67,6 +75,7 @@ text_to_cell_region (WorkbookControlGUI *wbcg,
 		     const char *opt_encoding,
 		     gboolean fixed_encoding)
 {
+	Workbook *wb = wb_control_workbook (WORKBOOK_CONTROL (wbcg));
 	DialogStfResult_t *dialogresult;
 	GnmCellRegion *cr = NULL;
 	gboolean oneline;
@@ -103,14 +112,17 @@ text_to_cell_region (WorkbookControlGUI *wbcg,
 	}
 
 	if (oneline) {
+		GODateConventions const *date_conv = workbook_date_conv (wb);
 		GnmCellCopy *cc = gnm_cell_copy_new (0, 0);
 
 		char *tmp = g_strndup (data, data_len);
 		g_free (data_converted);
-		cc->val = format_match (tmp, NULL,
-			workbook_date_conv (wb_control_workbook (WORKBOOK_CONTROL (wbcg))));
+		cc->val = format_match (tmp, NULL, date_conv);
+		if (cc->val)
+			g_free (tmp);
+		else
+			cc->val = value_new_string_nocopy (tmp);
 		cc->expr = NULL;
-		g_free (tmp);
 
 		cr = cellregion_new (NULL);
 		cr->content = g_slist_prepend (cr->content, cc);
@@ -122,7 +134,7 @@ text_to_cell_region (WorkbookControlGUI *wbcg,
 
 		if (dialogresult != NULL) {
 			cr = stf_parse_region (dialogresult->parseoptions,
-				dialogresult->text, NULL, wb_control_workbook (WORKBOOK_CONTROL (wbcg)));
+					       dialogresult->text, NULL, wb);
 			g_return_val_if_fail (cr != NULL, cellregion_new (NULL));
 
 			stf_dialog_result_attach_formats_to_cr (dialogresult, cr);
@@ -259,7 +271,7 @@ image_content_received (GtkClipboard *clipboard, GtkSelectionData *sel,
 
 static void
 table_content_received (GtkClipboard *clipboard, GtkSelectionData *sel,
-			  gpointer closure)
+			gpointer closure)
 {
 	GnmGtkClipboardCtxt *ctxt = closure;
 	WorkbookControlGUI *wbcg = ctxt->wbcg;
@@ -284,6 +296,14 @@ table_content_received (GtkClipboard *clipboard, GtkSelectionData *sel,
 		content = table_cellregion_read (wbc, "Gnumeric_html:html",
 						 pt, sel->data,
 						 sel->length);
+	} else if ((sel->target == gdk_atom_intern ( BIFF8_ATOM_NAME, FALSE)) ||
+		   (sel->target == gdk_atom_intern ( BIFF5_ATOM_NAME, FALSE)) ||
+		   (sel->target == gdk_atom_intern ( BIFF4_ATOM_NAME, FALSE)) ||
+		   (sel->target == gdk_atom_intern ( BIFF3_ATOM_NAME, FALSE)) ||
+		   (sel->target == gdk_atom_intern ( BIFF_ATOM_NAME,  FALSE))) {
+		content = table_cellregion_read (wbc, "Gnumeric_Excel:excel",
+						 pt, sel->data,
+						 sel->length);
 	}
 	if (content) {
 		/*
@@ -331,8 +351,16 @@ x_targets_received (GtkClipboard *clipboard, GdkAtom *targets,
 	/* in order of preference */
 	static char const *table_fmts [] = {
 		GNUMERIC_ATOM_NAME,
+
+		BIFF8_ATOM_NAME,
+		BIFF5_ATOM_NAME,
+		BIFF4_ATOM_NAME,
+		BIFF3_ATOM_NAME,
+		BIFF_ATOM_NAME,
+
 		OOO_ATOM_NAME,
 		OOO11_ATOM_NAME,
+
 		HTML_ATOM_NAME,
 		NULL
 	};
@@ -529,6 +557,49 @@ image_write (GnmCellRegion *cr, Sheet *sheet, gchar const *mime_type,
 	return ret;
 }
 
+static guchar *
+graph_write (GnmCellRegion *cr, Sheet *sheet, gchar const *mime_type,
+	     int *size)
+{
+	guchar *ret = NULL;
+	SheetObject *so = NULL;
+	GsfOutput *output;
+	GsfOutputMemory *omem;
+	gsf_off_t osize;
+	GSList *l;
+
+	*size = -1;
+
+	g_return_val_if_fail (cr->objects != NULL, NULL);
+	so = SHEET_OBJECT (cr->objects->data);
+	g_return_val_if_fail (so != NULL, NULL);
+
+	for (l = cr->objects; l != NULL; l = l->next) {
+		if (IS_SHEET_OBJECT_EXPORTABLE (SHEET_OBJECT (l->data))) {
+			so = SHEET_OBJECT (l->data);
+			break;
+		}
+	}
+	if (so == NULL) {
+		g_warning ("non exportable object requested\n");
+		return ret;
+	}
+	output = gsf_output_memory_new ();
+	omem   = GSF_OUTPUT_MEMORY (output);
+	sheet_object_write_object (so, mime_type, output, NULL);
+	osize = gsf_output_size (output);
+			
+	*size = osize;
+	if (*size == osize)
+		ret = g_memdup (gsf_output_memory_get_bytes (omem), *size);
+	else
+		g_warning ("Overflow");	/* Far fetched! */
+	gsf_output_close (output);
+	g_object_unref (output);
+
+	return ret;
+}
+
 static GString *
 cellregion_to_string (GnmCellRegion const *cr,
 		      GODateConventions const *date_conv)
@@ -554,7 +625,7 @@ cellregion_to_string (GnmCellRegion const *cr,
 		style = style_list_get_style (cr->styles,
 			src->col_offset, src->row_offset);
 		line = g_string_new (NULL);
-		format_value_gstring (line, mstyle_get_format (style),
+		format_value_gstring (line, gnm_style_get_format (style),
 				src->val, NULL, -1, date_conv);
 		data[src->row_offset][src->col_offset] = 
 			g_string_free (line, FALSE);
@@ -646,6 +717,14 @@ x_clipboard_get_cb (GtkClipboard *gclipboard, GtkSelectionData *selection_data,
 					selection_data->target, 8,
 					(guchar *) buffer, buffer_size);
 		g_free (buffer);
+	} else if (strcmp (target_name, "application/x-goffice-graph") == 0) {
+		int buffer_size;
+		guchar *buffer = graph_write (clipboard, sheet, target_name,
+					      &buffer_size);
+		gtk_selection_data_set (selection_data,
+					selection_data->target, 8,
+					(guchar *) buffer, buffer_size);
+		g_free (buffer);
 	} else if (strncmp (target_name, "image/", 6) == 0) {
 		int buffer_size;
 		guchar *buffer = image_write (clipboard, sheet, target_name,
@@ -760,7 +839,7 @@ x_claim_clipboard (WorkbookControlGUI *wbcg)
 {
 	GdkDisplay *display = gtk_widget_get_display (GTK_WIDGET (wbcg_toplevel (wbcg)));
 	GnmCellRegion *content = gnm_app_clipboard_contents_get ();
-	SheetObject *imageable = NULL;
+	SheetObject *imageable = NULL, *exportable = NULL;
 	GtkTargetEntry *targets = NULL;
 	int n_targets, i;
 	GSList *ptr;
@@ -782,13 +861,22 @@ x_claim_clipboard (WorkbookControlGUI *wbcg)
 		for (ptr = content->objects; ptr != NULL;
 		     ptr = ptr->next) {
 			candidate = SHEET_OBJECT (ptr->data);
-			if (IS_SHEET_OBJECT_IMAGEABLE (candidate)) {
+			if (IS_SHEET_OBJECT_EXPORTABLE (candidate)) {
+				exportable = candidate;
+				break;
+			} else if (IS_SHEET_OBJECT_IMAGEABLE (candidate)) {
 				imageable = candidate;
 				break;
 			}
 		}
 	}
-	if (imageable) {
+	if (exportable) {
+		tl = sheet_object_exportable_get_target_list (exportable);
+		/* _add_table prepends to target_list */
+		gtk_target_list_add_table (tl, table_targets, 1);
+		targets = target_list_to_entries (tl, &n_targets);
+		gtk_target_list_unref (tl);
+	} else if (imageable) {
 		tl = sheet_object_get_target_list (imageable);
 		/* _add_table prepends to target_list */
 		gtk_target_list_add_table (tl, table_targets, 1);
@@ -812,7 +900,7 @@ x_claim_clipboard (WorkbookControlGUI *wbcg)
 		(GtkClipboardClearFunc) x_clipboard_clear_cb,
 		G_OBJECT (wbcg));
 
-	if (imageable) {
+	if (exportable || imageable) {
 		for (i = 0; i < n_targets; i++)
 			g_free (targets[i].target);
 		g_free (targets);
