@@ -275,7 +275,6 @@ print_page_repeated_intersect (PrintJobInfo const *pj, Sheet const *sheet,
 static PangoLayout *
 ensure_decoration_layout (PrintJobInfo *pj)
 {
-
 	if (!pj->decoration_layout) {
 		PangoLayout *layout = gnome_print_pango_create_layout (pj->print_context);
 		/*
@@ -763,7 +762,7 @@ compute_scale_fit_to (PrintJobInfo const *pj, Sheet const *sheet,
 
 static int
 print_range_down_then_across (PrintJobInfo const *pj, Sheet const *sheet,
-			     GnmRange const *r, gboolean output)
+			      GnmRange const *r, gboolean output)
 {
 	PrintInformation *pi = sheet->print_info;
 	double usable_x, usable_x_initial, usable_x_repeating;
@@ -1017,7 +1016,7 @@ print_sheet_range (PrintJobInfo *pj, Sheet const *sheet,
 
 /*
  * code to count the number of pages that will be printed.
- * Unfortuantely a lot of data here is caclualted again when you
+ * Unfortuantely a lot of data here is calculated again when you
  * actually print the page ...
  */
 
@@ -1263,6 +1262,7 @@ dialog_response (GtkDialog *dialog, gint id,
 	switch (id) {
 	case GNOME_PRINT_DIALOG_RESPONSE_PRINT:
 	case GNOME_PRINT_DIALOG_RESPONSE_PREVIEW:
+		state->pj->render_info->page = 1;
 		state->sheet = wbcg_cur_sheet (state->wbcg);
 		range = gnome_print_dialog_get_range_page (
 			GNOME_PRINT_DIALOG (state->dialog), &first, &end);
