@@ -27,9 +27,19 @@ struct _RenderedValue {
 	guint wrap_text : 1;
 	guint might_overflow : 1;   /* Subject to ####### treatment.  */
 	guint numeric_overflow : 1; /* ####### has happened.  */
+	guint noborders : 1;        /* Valid for rotated only.  */
 	signed int rotation : 10;
 };
 
+struct _RenderedRotatedValue {
+	RenderedValue rv;
+	PangoMatrix rotmat;
+	int linecount;
+	struct RenderedRotatedValueInfo {
+		int dx, dy;
+	} *lines;	
+};
+
 RenderedValue *rendered_value_new     (GnmCell *cell, GnmStyle const *mstyle,
 				       gboolean variable_width,
 				       PangoContext *context,
