@@ -3,7 +3,7 @@
 /*
  * filter.c: support for filters
  *
- * Copyright (C) 2002-2004 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2005 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 #include <gnumeric-config.h>
@@ -39,14 +39,16 @@
 #include "dialogs.h"
 #include "style-color.h"
 #include "gutils.h"
-#include <goffice/utils/regutf8.h>
 
+#include <goffice/utils/regutf8.h>
 #include <goffice/cut-n-paste/foocanvas/foo-canvas-widget.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkevents.h>
 #include <gdk/gdkkeysyms.h>
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n.h>
+#include <string.h>
+#include <stdlib.h>
 
 typedef struct {
 	SheetObject parent;
@@ -342,7 +344,6 @@ collect_unique_elements (GnmFilterField *field,
 	/* r.end.row =  XL actually extend to the first non-empty element in the list */
 	r.end.col = r.start.col += filter_field_index (field);
 	uc.has_blank = FALSE;
-#warning "FIXME: is this really the type of equality (and hash) we want here?"
 	uc.hash = g_hash_table_new (
 			(GHashFunc) value_hash, (GEqualFunc) value_equal);
 	sheet_foreach_cell_in_range (field->filter->sheet,
@@ -441,6 +442,10 @@ cb_filter_button_pressed (GtkButton *button, FooCanvasItem *view)
 	frame = gtk_frame_new (NULL);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_OUT);
 
+	range_dump (&so->anchor.cell_bound, "");
+#if 0
+	fprintf (stderr, " : so = %p, view = %p\n", so, view);
+#endif
 	if (clip != NULL) {
 		GdkRectangle  rect;
 		GtkWidget *sw = gtk_scrolled_window_new (
@@ -564,8 +569,8 @@ filter_foo_view_init (SheetObjectViewIface *sov_iface)
 typedef FooCanvasWidget		FilterFooView;
 typedef FooCanvasWidgetClass	FilterFooViewClass;
 static GSF_CLASS_FULL (FilterFooView, filter_foo_view,
-	NULL, NULL,
-	FOO_TYPE_CANVAS_WIDGET, 0,
+	NULL, NULL, NULL, NULL,
+	NULL, FOO_TYPE_CANVAS_WIDGET, 0,
 	GSF_INTERFACE (filter_foo_view_init, SHEET_OBJECT_VIEW_TYPE))
 
 static SheetObjectView *
@@ -614,7 +619,6 @@ filter_field_class_init (GObjectClass *object_class)
 	/* SheetObject class method overrides */
 	sheet_object_class->new_view	  = filter_field_new_view;
 	sheet_object_class->read_xml_dom  = NULL;
-	sheet_object_class->write_xml_dom = NULL;
 	sheet_object_class->write_xml_sax = NULL;
 	sheet_object_class->print         = NULL;
 	sheet_object_class->copy          = NULL;
@@ -628,9 +632,9 @@ GSF_CLASS (GnmFilterField, filter_field,
 
 typedef struct  {
 	GnmFilterCondition const *cond;
+	GODateConventions const  *date_conv;
 	GnmValue		 *val[2];
-	go_regex_t  regexp[2];
-	GODateConventions const *date_conv;
+	GORegexp  		  regexp[2];
 } FilterExpr;
 
 static void
@@ -648,7 +652,7 @@ filter_expr_init (FilterExpr *fexpr, unsigned i,
 		if (fexpr->val[i] != NULL)
 			return;
 		if ((op == GNM_FILTER_OP_EQUAL || op == GNM_FILTER_OP_NOT_EQUAL) &&
-		    gnumeric_regcomp_XL (fexpr->regexp + i,  str, REG_ICASE) == REG_OK)
+		    gnm_regcomp_XL (fexpr->regexp + i,  str, REG_ICASE) == REG_OK)
 			return;
 	}
 	fexpr->val[i] = value_dup (tmp);
@@ -664,18 +668,23 @@ filter_expr_release (FilterExpr *fexpr, unsigned i)
 }
 
 static gboolean
-filter_expr_eval (GnmFilterOp op, GnmValue const *src, go_regex_t const *regexp,
+filter_expr_eval (GnmFilterOp op, GnmValue const *src, GORegexp const *regexp,
 		  GnmValue *target)
 {
 	GnmValDiff cmp;
 
 	if (src == NULL) {
 		char const *str = value_peek_string (target);
-		regmatch_t rm;
+		GORegmatch rm;
 
 		switch (go_regexec (regexp, str, 1, &rm, 0)) {
-		case REG_NOMATCH: return op == GNM_FILTER_OP_NOT_EQUAL;
-		case REG_OK: return op == GNM_FILTER_OP_EQUAL;
+		case REG_OK:
+			if (rm.rm_so == 0 && strlen (str) == (size_t)rm.rm_eo)
+				return op == GNM_FILTER_OP_EQUAL;
+			/* fall through */
+
+		case REG_NOMATCH:
+			return op == GNM_FILTER_OP_NOT_EQUAL;
 
 		default:
 			g_warning ("Unexpected regexec result");
