@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 #include <gnumeric-config.h>
@@ -59,7 +59,7 @@ range_row_cmp (GnmRange const *a, GnmRange const *b)
  */
 gboolean
 sheet_merge_add (Sheet *sheet, GnmRange const *r, gboolean clear,
-		 GnmCmdContext *cc)
+		 GOCmdContext *cc)
 {
 	GSList *test;
 	GnmRange  *r_copy;
@@ -76,7 +76,7 @@ sheet_merge_add (Sheet *sheet, GnmRange const *r, gboolean clear,
 	test = sheet_merge_get_overlap (sheet, r);
 	if (test != NULL) {
 		if (cc != NULL)
-			gnm_cmd_context_error (cc, g_error_new (gnm_error_invalid(), 0,
+			go_cmd_context_error (cc, g_error_new (go_error_invalid(), 0,
 				_("There is already a merged region that intersects\n%s!%s"),
 				sheet->name_unquoted, range_name (r)));
 		g_slist_free (test);
@@ -103,10 +103,10 @@ sheet_merge_add (Sheet *sheet, GnmRange const *r, gboolean clear,
 					    cc);
 
 		/* Apply the corner style to the entire region */
-		style = mstyle_copy (sheet_style_get (sheet, r->start.col,
+		style = gnm_style_dup (sheet_style_get (sheet, r->start.col,
 						      r->start.row));
 		for (i = MSTYLE_BORDER_TOP; i <= MSTYLE_BORDER_DIAGONAL; i++)
-			mstyle_unset_element (style, i);
+			gnm_style_unset_element (style, i);
 		sheet_style_apply_range (sheet, r, style);
 		sheet_region_queue_recalc (sheet, r);
 	}
@@ -159,7 +159,7 @@ sheet_merge_add (Sheet *sheet, GnmRange const *r, gboolean clear,
  * returns TRUE if there was an error.
  */
 gboolean
-sheet_merge_remove (Sheet *sheet, GnmRange const *r, GnmCmdContext *cc)
+sheet_merge_remove (Sheet *sheet, GnmRange const *r, GOCmdContext *cc)
 {
 	GnmRange   *r_copy;
 	GnmCell    *cell;
