@@ -4,6 +4,6 @@
 #include <gnumeric.h>
 
 void stf_init (void);
-void stf_text_to_columns (WorkbookControl *wbc, GnmCmdContext *cc);
+void stf_text_to_columns (WorkbookControl *wbc, GOCmdContext *cc);
 
 #endif /* GNUMERIC_STF_H */
