@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 #include <gnumeric-config.h>
@@ -103,9 +103,6 @@ WBC_VIRTUAL_FULL (sheet_remove, sheet.remove,
 	(WorkbookControl *wbc, Sheet *sheet), (wbc, sheet))
 WBC_VIRTUAL_FULL (sheet_focus, sheet.focus,
 	(WorkbookControl *wbc, Sheet *sheet), (wbc, sheet))
-WBC_VIRTUAL_FULL (sheet_move, sheet.move,
-	(WorkbookControl *wbc, Sheet *sheet, int new_pos),
-	(wbc, sheet, new_pos))
 WBC_VIRTUAL_FULL (sheet_remove_all, sheet.remove_all,
 	(WorkbookControl *wbc), (wbc))
 
@@ -253,7 +250,7 @@ wb_control_parse_and_jump (WorkbookControl *wbc, char const *text)
 				b.row = r->end.row;
 				a.col_relative = a.row_relative = b.col_relative = b.row_relative = FALSE;
 				pp.sheet = NULL; /* make it a global name */
-				if (cellref_equal (&a, &b))
+				if (gnm_cellref_equal (&a, &b))
 					target_range = gnm_expr_new_cellref (&a);
 				else
 					target_range = gnm_expr_new_constant (
