@@ -185,8 +185,18 @@ xml_node_get_value (xmlNodePtr node, char const *name)
 	gchar     *vstr;
 
 	str  = xml_node_get_cstr (node, name);
+	if (!str) {
+		/* This happens because the sax writer as-of 1.6.1 does
+		   not write these fields.  */
+		return value_new_error_NA (NULL);
+	}
 	type = (GnmValueType) atoi (str);
+
 	vstr = g_strrstr (str, ":") + 1;
+	if (!vstr) {
+		g_warning ("File corruption [%s] [%s]", name, str);
+		return value_new_error_NA (NULL);
+	}
 
 	value = value_new_from_string (type, vstr, NULL, FALSE);
 	xmlFree (str);
@@ -1615,7 +1625,7 @@ xml_read_scenarios (XmlParseContext *ctxt, xmlNodePtr tree)
 			g_string_append_printf (name, "V%d", i);
 			s->changing_cells [i] = xml_node_get_value (child,
 								    name->str);
-			g_string_free (name, FALSE);
+			g_string_free (name, TRUE);
 		}
 
 		sheet->scenarios = g_list_append (sheet->scenarios, s);
@@ -1929,6 +1939,8 @@ xml_sheet_read (XmlParseContext *ctxt, xmlNodePtr tree)
 		g_object_set (sheet, "display-outlines-right", tmp, NULL);
 	if (xml_node_get_bool (tree, "RTL_Layout", &tmp))
 		g_object_set (sheet, "text-is-rtl", tmp, NULL);
+	if (xml_node_get_bool (tree, "Protected", &tmp))
+		g_object_set (sheet, "protected", tmp, NULL);
 	if (xml_node_get_enum (tree, "Visibility", GNM_SHEET_VISIBILITY_TYPE, &tmpi))
 		g_object_set (sheet, "visibility", tmpi, NULL);
 	sheet->tab_color = xml_node_get_color (tree, "TabColor");
